import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:testlab/models/card.dart';
import 'package:testlab/presentaition/details_page/details_page.dart';

part 'card.dart';

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final Color _color = Colors.grey.shade600;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
          backgroundColor: _color,
          title: Text(
            widget.title,
            style: const TextStyle(
              color: Colors.white,
              fontSize: 20,
            ),
          ),
      ),
      body: const Body(),
    );
  }
}

class Body extends StatelessWidget {
  const Body({super.key});

  @override
  Widget build(BuildContext context) {
    final data = [
      CardData(
        'Mobile dev',
        descriptionText: 'И когда ты успел стать экспертом в мобильной разработке?',
        imageUrl:
        'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcQtsv2O-lLpxro9HH9CUejcymOOnGdQJwjasg&s',
      ),
      CardData(
        'Грустный кот',
        descriptionText: 'Котик грустит, аж плачет',
        icon: Icons.star,
        imageUrl:
        'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcT--ZMDGsa_8y9r9u0RjAn576ajsVVfsOIcDA&s',
      ),
      CardData(
        'Веселый кот',
        descriptionText: 'Котик стал очень веселый, аж улыбается',
        icon: Icons.work,
        imageUrl:
        'https://img-webcalypt.ru/storage/memes/YhGTdxW7HnbmhqAd37XjsMCTj1fHUW7AADagYMDbmyU9VBEhDBbq4d3XNGDWo34FibwtjyeVsyxudpzeViSmHdJ7e6C50tLbZnkZZAP81AV7aM0R8VSi4YEnqgcZ1EtE-md.jpeg',
      ),
      CardData(
        'Кот накачаля',
        descriptionText: 'Кот накачался, аж широкий',
        icon: Icons.question_answer,
        imageUrl:
        'https://s00.yaplakal.com/pics/pics_original/9/1/8/11586819.jpg',
      ),
      CardData(
        'Кот крутой',
        descriptionText: 'Кот стал очень крутым, аж в очках',
        icon: Icons.favorite_border,
        imageUrl:
        'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcSmwxp_mc1c8Rukc6Dg4GLNv1JLZbO7DKqF4w&s',
      ),
    ];
    return Center(
      child: SingleChildScrollView(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: data.map((data) {
            return _Card.fromData(
              data,
              onLike: (String title, bool isLiked) =>
                  _showSnackBar(context, title, isLiked),
              onTap: () => _navToDetails(context, data),
            );
          }).toList(),
        ),
      ),
    );
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          'You ${isLiked ? 'like!' : 'disliked :('} $title ',
          style: const TextStyle(
            color: Colors.white,
            fontSize: 18,
            fontWeight: FontWeight.bold,
          ),
        ),
        backgroundColor: Colors.black,
        duration: const Duration(seconds: 1),
      ));
    });
  }}